from setuptools import setup, find_packages

setup(
    name='GAO',
    version='0.1.1',
    description='Gis Application Objects',
    author='Gao Zhiheng',
    author_email='11279470@qq.com',
    packages=find_packages(),
    install_requires=[
        # Add any dependencies required by your package here
    ],
)

